@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -38,7 +38,7 @@ void NonBreakingSpacePluginEditorInterface::createAction(KActionCollection *ac)
     ac->addAction(QStringLiteral("insert_non_breaking_space"), action);
     ac->setDefaultShortcut(action, Qt::CTRL + Qt::Key_Space);
     connect(action, &QAction::triggered, this, &NonBreakingSpacePluginEditorInterface::slotActivated);
-    MessageComposer::ActionType type(action, MessageComposer::ActionType::Edit);
+    MessageComposer::PluginActionType type(action, MessageComposer::PluginActionType::Edit);
     setActionType(type);
 }
 
