@@ -22,8 +22,6 @@
 
 #include <MessageViewer/BodyPartURLHandler>
 
-#include <KCalCore/Event>
-
 #include <QObject>
 
 class SemanticMemento;
@@ -33,7 +31,7 @@ class SemanticUrlHandler : public QObject, public MessageViewer::Interface::Body
 {
     Q_OBJECT
 public:
-    SemanticUrlHandler() = default;
+    SemanticUrlHandler();
     ~SemanticUrlHandler() override = default;
 
     bool handleClick(MessageViewer::Viewer *viewerInstance, MimeTreeParser::Interface::BodyPart *part, const QString &path) const override;
@@ -44,12 +42,10 @@ private:
     SemanticMemento *memento(MimeTreeParser::Interface::BodyPart *part) const;
     QDate dateForReservation(SemanticMemento *memento) const;
     void showCalendar(const QDate &date) const;
-
-    KCalCore::Event::Ptr eventForReservation(const QVariant &reservation) const;
-    KCalCore::Event::Ptr eventForFlightReservation(const QVariant &reservation) const;
-    KCalCore::Event::Ptr eventForLodgingReservation(const QVariant &reservation) const;
-    KCalCore::Event::Ptr eventForTrainReservation(const QVariant &reservation) const;
     void addToCalendar(SemanticMemento *memento) const;
+    void openInApp(MimeTreeParser::Interface::BodyPart *part) const;
+
+    QString m_appPath;
 };
 
 #endif // SEMANTICURLHANDLER_H
