@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@ class SelectImapWidget : public KSieveUi::AbstractMoveImapFolderWidget
     Q_OBJECT
 public:
     explicit SelectImapWidget(QWidget *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
-    ~SelectImapWidget();
+    ~SelectImapWidget() override;
 
     void setText(const QString &str) override;
     QString text() const override;
